==> flink-1.13.6-src.tgz: flink-1.13.6/flink-core/src/test/java/org/apache/flink/api/java/typeutils/ObjectArrayTypeInfoTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.api.java.typeutils;

import org.apache.flink.api.common.typeutils.TypeInformationTestBase;

import java.util.ArrayList;

/** Test for {@link ObjectArrayTypeInfo}. */
public class ObjectArrayTypeInfoTest extends TypeInformationTestBase<ObjectArrayTypeInfo<?, ?>> {

    @Override
    protected ObjectArrayTypeInfo<?, ?>[] getTestData() {
        return new ObjectArrayTypeInfo<?, ?>[] {
            ObjectArrayTypeInfo.getInfoFor(
                    TestClass[].class, new GenericTypeInfo<>(TestClass.class)),
            ObjectArrayTypeInfo.getInfoFor(
                    TestClass[].class,
                    new PojoTypeInfo<>(TestClass.class, new ArrayList<PojoField>()))
        };
    }

    public static class TestClass {}
}

==> flink-2.1.1-src.tgz: flink-2.1.1/flink-core/src/test/java/org/apache/flink/api/java/typeutils/ObjectArrayTypeInfoTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.api.java.typeutils;

import org.apache.flink.api.common.typeutils.TypeInformationTestBase;

import java.util.ArrayList;

/** Test for {@link ObjectArrayTypeInfo}. */
class ObjectArrayTypeInfoTest extends TypeInformationTestBase<ObjectArrayTypeInfo<?, ?>> {

    @Override
    protected ObjectArrayTypeInfo<?, ?>[] getTestData() {
        return new ObjectArrayTypeInfo<?, ?>[] {
            ObjectArrayTypeInfo.getInfoFor(
                    TestClass[].class, new GenericTypeInfo<>(TestClass.class)),
            ObjectArrayTypeInfo.getInfoFor(
                    TestClass[].class,
                    new PojoTypeInfo<>(TestClass.class, new ArrayList<PojoField>()))
        };
    }

    public static class TestClass {}
}
